.. include:: ../BADGES.rst

.. _dapclient_documentation:

dapclient
=========

dapclient is a pure `Python <http://python.org/>`_ library implementing the
`Data Access Protocol <http://opendap.org/>`_, also known as **DODS** or
**OPeNDAP**. You can use dapclient as a `client <client.html>`_ to access
hundreds of scientific datasets in a transparent and efficient way through the
internet

Table of Contents
-----------------

.. toctree::
   :maxdepth: 2

   readme
   client
   handlers
   responses
   contributing
   developer
   authors
   license

Other Projects
--------------
http://timcera.bitbucket.io
